require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xiissession',
  dscmeta_resource_friendly_name: 'xIISSession',
  dscmeta_resource_name: 'xIISSession',
  dscmeta_resource_implementation: 'Binary',
  dscmeta_module_name: 'xIISSession',
  dscmeta_module_version: '1.0.0.0',
  docs: 'The DSC xIISSession resource type.
         Automatically generated from version 1.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_mode: {
      type: "Enum['Off', 'InProc', 'StateServer', 'SQLServer', 'Custom']",
      desc: ' ',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_usestate: {
      type: 'Optional[Struct[{
              compressionenabled => Optional[Boolean],
              stateconnectionstring => Optional[String],
              statenetworktimeout => Optional[String],
            }]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UseState',
      mof_is_embedded: true,
    },
    dsc_usesql: {
      type: 'Optional[Struct[{
              sqlconnectionstring => Optional[String],
              compressionenabled => Optional[Boolean],
              allowcustomsqldatabase => Optional[Boolean],
              sqlcommandtimeout => Optional[String],
              sqlconnectionretryinterval => Optional[String]
            }]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UseSQL',
      mof_is_embedded: true,
    },
    dsc_usecookie: {
      type: "Optional[Struct[{
              regenerateexpiredsessionid => Optional[Boolean],
              cookiename => Optional[String],
              timeout => Optional[String],
              usehostingidentity => Optional[Boolean],
              cookieless => Optional[Enum['UseUri', 'UseCookies', 'AutoDetect', 'UseDeviceProfile']]
            }]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UseCookie',
      mof_is_embedded: true,
    },
    dsc_sitename: {
      type: 'String',
      desc: ' ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
